flexmix, it
should usually not be used directly.FLXfit(model, concomitant, control, postunscaled = NULL, groups, weights)FLXMx objects.FLXconcomitant.FLXcontrol.group which is a factor with
optional grouping of observations and groupfirst which is a
logical vector for the first observation of each group.flexmix.flexmix, flexmix-class