| compatibility-aliases | R Documentation |
These functions are renamed versions of model drivers included for backward compatibility.
FLXglm(formula = . ~ .,
family = c("gaussian", "binomial", "poisson", "Gamma"),
offset = NULL)
FLXglmFix(formula = . ~ ., fixed = ~0, varFix = FALSE, nested = NULL,
family = c("gaussian", "binomial", "poisson", "Gamma"),
offset = NULL)
FLXmclust(formula = . ~ ., diagonal = TRUE)
FLXbclust(formula = . ~ ., truncated = FALSE)
FLXconstant()
FLXmultinom(formula = ~1)
formula |
For component model drivers, a formula which is
interpreted relative to the formula specified in the call to
|
family |
A character string naming a |
offset |
This can be used to specify an a priori known component to be included in the linear predictor during fitting. |
fixed |
A formula which specifies the additional regressors for the fixed (constant) coefficients. |
varFix |
A logical indicating if the variance estimate for Gaussian components should be constrained to be equal for all components. It can be also a vector specifying the number of components with equal variance. |
nested |
An object of class |
diagonal |
If |
truncated |
A logical, if |
The functions map to the current implementations as follows:
FLXglm aliases FLXMRglm.
FLXglmFix aliases FLXMRglmfix.
FLXmclust aliases FLXMCmvnorm.
FLXbclust aliases FLXMCmvbinary.
FLXmultinom aliases FLXPmultinom.
FLXconstant aliases FLXPconstant.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.