These functions are renamed versions of model drivers included for backward compatibility.
FLXglm(formula = . ~ .,
family = c("gaussian", "binomial", "poisson", "Gamma"),
offset = NULL)
FLXglmFix(formula = . ~ ., fixed = ~0, varFix = FALSE, nested = NULL,
family = c("gaussian", "binomial", "poisson", "Gamma"),
offset = NULL)
FLXmclust(formula = . ~ ., diagonal = TRUE)
FLXbclust(formula = . ~ ., truncated = FALSE)
FLXconstant()
FLXmultinom(formula = ~1)
For component model drivers, a formula which is
interpreted relative to the formula specified in the call to
flexmix using update.formula. Default is
to use the original flexmix model formula. For
concomitant model drivers, a formula for determining the model
matrix of the concomitant variables.
A character string naming a glm
family function.
This can be used to specify an a priori known component to be included in the linear predictor during fitting.
A formula which specifies the additional regressors for the fixed (constant) coefficients.
A logical indicating if the variance estimate for Gaussian components should be constrained to be equal for all components. It can be also a vector specifying the number of components with equal variance.
An object of class FLXnested or a list specifying
the nested structure.
If TRUE, then the covariance matrix of the
components is restricted to diagonal matrices.
A logical, if TRUE the observations for the
pattern with only zeros are missing and the truncated likelihood is
optimized using an EM-algorithm.
The functions map to the current implementations as follows:
FLXglm aliases FLXMRglm.
FLXglmFix aliases FLXMRglmfix.
FLXmclust aliases FLXMCmvnorm.
FLXbclust aliases FLXMCmvbinary.
FLXmultinom aliases FLXPmultinom.
FLXconstant aliases FLXPconstant.